/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_DirectoryBinding_h
#define mozilla_dom_DirectoryBinding_h

#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/Nullable.h"
#include "mozilla/dom/UnionTypes.h"

namespace mozilla {
namespace dom {

struct CreateFileOptionsAtoms;
class Directory;
struct DirectoryAtoms;
struct NativePropertyHooks;
class OwningStringOrBlobOrArrayBufferOrArrayBufferView;
class ProtoAndIfaceCache;
class StringOrBlobOrArrayBufferOrArrayBufferView;

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {

MOZ_BEGIN_ENUM_CLASS(CreateIfExistsMode, uint32_t)
  Replace,
  Fail,
  EndGuard_
MOZ_END_ENUM_CLASS(CreateIfExistsMode)

namespace CreateIfExistsModeValues {
extern const EnumEntry strings[3];
} // namespace CreateIfExistsModeValues


struct CreateFileOptions : public DictionaryBase
{
  Optional<OwningStringOrBlobOrArrayBufferOrArrayBufferView> mData;
  CreateIfExistsMode mIfExists;

  CreateFileOptions();

protected:
  explicit inline CreateFileOptions(int )
  {
    // Do nothing here; this is used by our "Fast" subclass
  }

private:
  CreateFileOptions(const CreateFileOptions&) MOZ_DELETE;
  void operator=(const CreateFileOptions) MOZ_DELETE;

  static bool
  InitIds(JSContext* cx, CreateFileOptionsAtoms* atomsCache);

public:
  bool
  Init(JSContext* cx, JS::Handle<JS::Value> val, const char* sourceDescription = "Value");

  bool
  Init(const nsAString& aJSON);

  bool
  ToObjectInternal(JSContext* cx, JS::MutableHandle<JS::Value> rval) const;

  void
  TraceDictionary(JSTracer* trc);
};

namespace binding_detail {
struct FastCreateFileOptions : public CreateFileOptions
{
  inline FastCreateFileOptions()
    : CreateFileOptions(42)
  {
    // Doesn't matter what int we pass to the parent constructor
  }
};
} // namespace binding_detail


namespace DirectoryBinding {

  typedef mozilla::dom::Directory NativeType;

  // We declare this as an array so that retrieving a pointer to this
  // binding's property hooks only requires compile/link-time resolvable
  // address arithmetic.  Declaring it as a pointer instead would require
  // doing a run-time load to fetch a pointer to this binding's property
  // hooks.  And then structures which embedded a pointer to this structure
  // would require a run-time load for proper initialization, which would
  // then induce static constructors.  Lots of static constructors.
  extern const NativePropertyHooks sNativePropertyHooks[];

  const JSClass*
  GetJSClass();

  JSObject*
  Wrap(JSContext* aCx, mozilla::dom::Directory* aObject, nsWrapperCache* aCache);

  template <class T>
  inline JSObject* Wrap(JSContext* aCx, T* aObject)
  {
    return Wrap(aCx, aObject, aObject);
  }

  void
  CreateInterfaceObjects(JSContext* aCx, JS::Handle<JSObject*> aGlobal, ProtoAndIfaceCache& aProtoAndIfaceCache, bool aDefineOnGlobal);

  JS::Handle<JSObject*>
  GetProtoObject(JSContext* aCx, JS::Handle<JSObject*> aGlobal);

} // namespace DirectoryBinding



} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_DirectoryBinding_h
